#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 entropy
version:              0.4.1.6
visibility:           public
id:                   entropy-0.4.1.6-mwZ4jE2F7MEzr0ctFVs6J
key:                  entropy-0.4.1.6-mwZ4jE2F7MEzr0ctFVs6J
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             https://github.com/TomMD/entropy
synopsis:             A platform independent entropy source
description:
    A mostly platform independent method to obtain cryptographically strong entropy
    (RDRAND, urandom, CryptAPI, and patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.

category:             Data, Cryptography
abi:                  c42808aed1aadbb13ed292e039c32840
exposed:              True
exposed-modules:      System.Entropy
hidden-modules:       System.EntropyNix
import-dirs:          /usr/lib/ghc-8.10.5/site-local/entropy-0.4.1.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/entropy-0.4.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/entropy-0.4.1.6
hs-libraries:         HSentropy-0.4.1.6-mwZ4jE2F7MEzr0ctFVs6J
depends:              base-4.14.2.0 bytestring-0.10.12.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html:         /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

